@@ -50,6 +50,7 @@ from Products.PloneFormGen.content.formMailerAdapter import formMailerAdapterSch
 from Products.PloneFormGen import HAS_PLONE25, HAS_PLONE30
 #from Products.PloneFormGen.interfaces import IPloneFormGenField
 from Products.PloneFormGen.content.fieldsBase import BaseFormField
+from Products.PloneFormGen.content.thanksPage import FormThanksPage, ThanksPageSchema
 
 from Products.PFGVerkkomaksut import PFGVerkkomaksutMessageFactory as _
 from Products.PFGVerkkomaksut.config import PROJECTNAME
@@ -63,7 +64,7 @@ def check_float(value):
     except TypeError:
         return False
 
-PFGVerkkomaksutSchema = ATFolderSchema.copy() + formMailerAdapterSchema.copy() + Schema((
+PFGVerkkomaksutSchema = ATFolderSchema.copy() + formMailerAdapterSchema.copy() + ThanksPageSchema.copy() + Schema((
 
     BooleanField(
         name='msg_necessary',
@@ -169,23 +170,23 @@ PFGVerkkomaksutSchema = ATFolderSchema.copy() + formMailerAdapterSchema.copy() +
         default_method='field_ids',
     ),
 
-    TextField(
-        name='thanks_text',
-        schemata='verkkomaksut',
-        required=False,
-        searchable=False,
-        storage = AnnotationStorage(),
-        primary=True,
-        validators = ('isTidyHtmlWithCleanup',),
-        default_output_type = 'text/x-html-safe',
-#        widget = TextAreaWidget(
-        widget = RichWidget(
-            label = _(u'Thanks Text'),
-            description=_(u'This thanks text will be displayed when payment is successful.'),
-            rows = 25,
-            allow_file_upload = zconf.ATDocument.allow_document_upload,
-              ),
-    ),
+#    TextField(
+#        name='thanks_text',
+#        schemata='verkkomaksut',
+#        required=False,
+#        searchable=False,
+#        storage = AnnotationStorage(),
+#        primary=True,
+#        validators = ('isTidyHtmlWithCleanup',),
+#        default_output_type = 'text/x-html-safe',
+##        widget = TextAreaWidget(
+#        widget = RichWidget(
+#            label = _(u'Thanks Text'),
+#            description=_(u'This thanks text will be displayed when payment is successful.'),
+#            rows = 25,
+#            allow_file_upload = zconf.ATDocument.allow_document_upload,
+#              ),
+#    ),
 
     StringField(
         name='cancel_message',
@@ -206,14 +207,21 @@ PFGVerkkomaksutSchema.moveField('msg_necessary', pos='top')
 PFGVerkkomaksutSchema.moveField('body_pt', before='body_pre')
 PFGVerkkomaksutSchema['body_pt'].schemata='message'
 PFGVerkkomaksutSchema['body_pt'].required=False
-#PFGVerkkomaksutSchema['msg_subject'].storage=AnnotationStorage()
+PFGVerkkomaksutSchema['thanksPrologue'].schemata='verkkomaksut'
+PFGVerkkomaksutSchema['thanksPrologue'].widget.label=_(u'Thanks Text')
+PFGVerkkomaksutSchema['thanksPrologue'].widget.description=_(u'This thanks text will be displayed when payment is successful.')
+PFGVerkkomaksutSchema.moveField('thanksPrologue', before='cancel_message')
+
+
+del PFGVerkkomaksutSchema['thanksEpilogue']
+del PFGVerkkomaksutSchema['noSubmitMessage']
 
 #finalizeATCTSchema(PFGVerkkomaksutSchema)
 finalizeATCTSchema(PFGVerkkomaksutSchema, folderish=True, moveDiscussion=False)
 
 #class PFGVerkkomaksut(FormActionAdapter, FormMailerAdapter):
 #class PFGVerkkomaksut(FormMailerAdapter):
-class PFGVerkkomaksut(ATFolder, FormMailerAdapter):
+class PFGVerkkomaksut(ATFolder, FormMailerAdapter, FormThanksPage):
 #class PFGVerkkomaksut(FormMailerAdapter, ATFolder):
     """Verkkomaksut Payment Adapter"""
 
@@ -268,7 +276,7 @@ class PFGVerkkomaksut(ATFolder, FormMailerAdapter):
 #        queries = ['&'+id+'='+form.get(id) for id in ids if form.get(id) is not None][1:]
 #        query = '?'+ids[0]+'='+form.get(ids[0])+''.join(queries)
         parent_url = parent.absolute_url()
-        return_url = '%s/verkkomaksut-thanks' % (self.absolute_url())
+        return_url = '%s/@@verkkomaksut-success' % (parent_url)
 #        message = 'AAA'
 #        IStatusMessage(REQUEST).addStatusMessage(message, type='info')
 #        parent.plone_utils.addPortalMessage(_(u'AAA'))
@@ -322,25 +330,30 @@ class PFGVerkkomaksut(ATFolder, FormMailerAdapter):
         )
 
         session.set('pfg.verkkomaksut', value)
-        res = [
-            dict(
-                title=field.Title(),
-                description=form.get(field.getId()),
-            ) for field in fields
-        ]
-#        for field in fields:
-#            id = field.getId()
-#            res.update({id:form.get(id)})
-        session.set('pfg.verkkomaksut.fields', res)
+#        res = [
+#            dict(
+#                title=field.Title(),
+#                description=form.get(field.getId()),
+#            ) for field in fields
+#        ]
+##        for field in fields:
+##            id = field.getId()
+##            res.update({id:form.get(id)})
+#        session.set('pfg.verkkomaksut.fields', res)
+        session.set('pfg.verkkomaksut.fields', self.displayInputs(REQUEST))
 
 
         url = '%s/verkkomaksut' % parent_url
         return self.REQUEST.RESPONSE.redirect(url)
 
     def order_description(self, fields, REQUEST=None):
-        form = self.REQUEST.form
-        values = [safe_unicode(form.get(key, '')) for key in self.getOrder_description()]
+        self.displayInputs(REQUEST)
+        values = [safe_unicode(item.get('value')) for item in self.displayInputs(REQUEST)]
+#        form = self.REQUEST.form
+#        values = [safe_unicode(form.get(key, '')) for key in self.getOrder_description()]
         res = u','.join(values)
+#        res = safe_unicode(res)
+#        return res[:65000]
         portal = getToolByName(self, 'portal_url').getPortalObject()
         charset = portal.getProperty('email_charset', 'utf-8')
         return res[:65000].encode(charset)
